@@ -25,6 +25,7 @@ from . import (
 from .config import CONFIG_DIR_NAME, CONFIG_FILENAME, ProjectConfig
 from .gallery import serve_gallery
 from .generator import GenerationResult, build_generator
+from .defaults import DEFAULT_GENERATOR, DEFAULT_PROVIDER, available_models, default_model_for_provider
 from .models import EffectiveParameters, SessionRequest
 from .storage import InvalidPathError, list_manifests_for_slot
 
@@ -38,8 +39,6 @@ def _env_flag(name: str) -> bool:
 
 GALLERY_HOST = os.environ.get("IMAGEMCP_GALLERY_HOST", "localhost")
 GALLERY_PORT = int(os.environ.get("IMAGEMCP_GALLERY_PORT", "8765"))
-DEFAULT_GENERATOR = os.environ.get("IMAGEMCP_DEFAULT_GENERATOR", "openrouter")
-DEFAULT_PROVIDER = os.environ.get("IMAGEMCP_DEFAULT_PROVIDER", "openrouter")
 GALLERY_LAUNCH_TIMEOUT = float(os.environ.get("IMAGEMCP_GALLERY_START_TIMEOUT", "5"))
 GALLERY_POLL_INTERVAL = float(os.environ.get("IMAGEMCP_GALLERY_POLL_INTERVAL", "0.2"))
 GALLERY_ALWAYS_RESTART = _env_flag("IMAGEMCP_GALLERY_ALWAYS_RESTART")
@@ -108,8 +107,10 @@ def build_parser() -> argparse.ArgumentParser:
     gen_parser.add_argument("--session-hint", help="Hint to include in session id")
     gen_parser.add_argument(
         "--generator",
-        default=DEFAULT_GENERATOR,
-        help=f"Generator backend (default: {DEFAULT_GENERATOR})",
+        default=None,
+        help=(
+            "Generator backend (default: openrouter; automatically switches to 'mock' when the provider is 'mock')"
+        ),
     )
     gen_parser.add_argument(
         "--json",
@@ -187,6 +188,10 @@ def build_parser() -> argparse.ArgumentParser:
     gallery_stop_parser.add_argument("--port", type=int, default=GALLERY_PORT)
     gallery_stop_parser.set_defaults(func=cmd_gallery_stop)
 
+    models_parser = subparsers.add_parser("models", help="List supported providers and models")
+    models_parser.add_argument("--provider", help="Filter results to a provider id")
+    models_parser.set_defaults(func=cmd_models)
+
     return parser
 
 
@@ -302,7 +307,10 @@ def _clear_global_gallery_state() -> None:
 
 
 def _launch_gallery_background(config: ProjectConfig, paths: ProjectPaths, host: str, port: int) -> subprocess.Popen[bytes]:
-    target_root = str(paths.target_root)
+    try:
+        target_root = paths.target_root.relative_to(paths.project_root).as_posix()
+    except ValueError:
+        target_root = str(paths.target_root)
     project_root = str(paths.project_root)
     cmd = [
         sys.executable,
@@ -454,21 +462,33 @@ def cmd_generate(args: argparse.Namespace) -> int:
     aspect_ratio = args.aspect_ratio or payload.aspect_ratio
     seed = args.seed if args.seed is not None else payload.seed
     provider = args.provider or payload.provider or DEFAULT_PROVIDER
-    model = args.model or payload.model
+    model = args.model or payload.model or default_model_for_provider(provider)
+    generator_name = (
+        (args.generator if args.generator else None)
+        or payload.generator
+        or ("mock" if provider == "mock" else DEFAULT_GENERATOR)
+    )
 
     request_text = args.request_text or payload.request_text or f"Generate {count} variants for {args.slot}"
 
-    generator = build_generator(ctx.session_dir, args.generator)
-    generation: GenerationResult = generator.generate(
-        payload.prompt,
-        count,
-        size=size,
-        aspect_ratio=aspect_ratio,
-        seed=seed,
-        provider=provider,
-        model=model,
-        provider_options=payload.provider_options,
-    )
+    try:
+        generator = build_generator(ctx.session_dir, generator_name)
+    except Exception as exc:  # pragma: no cover - depends on generator backend
+        return _handle_generator_exception(exc, config)
+
+    try:
+        generation: GenerationResult = generator.generate(
+            payload.prompt,
+            count,
+            size=size,
+            aspect_ratio=aspect_ratio,
+            seed=seed,
+            provider=provider,
+            model=model,
+            provider_options=payload.provider_options,
+        )
+    except Exception as exc:  # pragma: no cover - depends on generator backend
+        return _handle_generator_exception(exc, config)
 
     request = SessionRequest(request_text=request_text, created_by="cli")
     effective = EffectiveParameters(
@@ -479,6 +499,7 @@ def cmd_generate(args: argparse.Namespace) -> int:
         seed=seed,
         provider=provider,
         model=model,
+        generator=generator_name,
         provider_options=payload.provider_options,
     )
 
@@ -508,6 +529,7 @@ def cmd_generate(args: argparse.Namespace) -> int:
         "projectId": config.project_id,
         "projectName": config.project_name,
         "targetRoot": config.target_root,
+        "generator": generator_name,
     }
     if args.open_gallery:
         webbrowser.open(gallery_url, new=2)
@@ -709,6 +731,25 @@ def cmd_gallery_stop(args: argparse.Namespace) -> int:
     return 0
 
 
+def cmd_models(args: argparse.Namespace) -> int:
+    models = available_models()
+    if args.provider:
+        provider = args.provider.strip().lower()
+        options = models.get(provider)
+        if not options:
+            known = ", ".join(sorted(models)) or "(none)"
+            return _fail(f"Unknown provider '{provider}'. Known providers: {known}")
+        print(f"Provider: {provider}")
+        for model in options:
+            print(f"  - {model}")
+        return 0
+    for provider in sorted(models):
+        print(f"Provider: {provider}")
+        for model in models[provider]:
+            print(f"  - {model}")
+    return 0
+
+
 def _load_prompt_payload(prompt: Optional[str], prompt_file: Optional[str]) -> "PromptPayload":
     prompt_text = prompt
     request_text: Optional[str] = None
@@ -719,6 +760,7 @@ def _load_prompt_payload(prompt: Optional[str], prompt_file: Optional[str]) -> "
     aspect_override: Optional[str] = None
     seed_override: Optional[int] = None
     count_override: Optional[int] = None
+    generator_override: Optional[str] = None
 
     if prompt_file:
         raw = _read_input(prompt_file)
@@ -733,6 +775,7 @@ def _load_prompt_payload(prompt: Optional[str], prompt_file: Optional[str]) -> "
                 prompt_text = prompt_text or parsed.get("text")
                 provider = parsed.get("provider") or provider
                 model = parsed.get("model") or model
+                generator_override = parsed.get("generator") or generator_override
                 size_override = parsed.get("size") or size_override
                 aspect_override = parsed.get("aspectRatio") or aspect_override
                 seed_value = parsed.get("seed")
@@ -752,6 +795,7 @@ def _load_prompt_payload(prompt: Optional[str], prompt_file: Optional[str]) -> "
         provider_options=provider_options,
         provider=provider,
         model=model,
+        generator=generator_override,
         size=size_override,
         aspect_ratio=aspect_override,
         seed=seed_override,
@@ -817,6 +861,26 @@ def _fail(message: str) -> int:
     return 1
 
 
+def _handle_generator_exception(exc: Exception, config: ProjectConfig) -> int:
+    message = str(exc)
+    env_hint = config.project_root / ".env"
+    key_notice = "OpenRouter API key is missing"
+    if key_notice in message:
+        guidance = (
+            "OpenRouter API key is missing. Set OPENROUTER_API_KEY in your environment.\n"
+            f"Add a line like OPENROUTER_API_KEY=sk-... to {env_hint} and rerun the command; no extra 'source .env' step is required because the CLI reloads the file automatically.\n"
+            "If the key is unavailable, ask the user to provide a valid OpenRouter API token before continuing."
+        )
+        return _fail(guidance)
+    if "not a valid model ID" in message:
+        guidance = (
+            "OpenRouter rejected the requested model. Use the default `google/gemini-2.5-flash-image-preview` or consult "
+            "resource setup://imgen-parameters. Run `imgen models` to list supported options."
+        )
+        return _fail(guidance)
+    return _fail(f"Generator error ({exc.__class__.__name__}): {message}")
+
+
 class PromptPayload:
     def __init__(
         self,
@@ -826,6 +890,7 @@ class PromptPayload:
         provider_options: Dict[str, Any],
         provider: Optional[str],
         model: Optional[str],
+        generator: Optional[str],
         size: Optional[str],
         aspect_ratio: Optional[str],
         seed: Optional[int],
@@ -836,6 +901,7 @@ class PromptPayload:
         self.provider_options = provider_options
         self.provider = provider
         self.model = model
+        self.generator = generator
         self.size = size
         self.aspect_ratio = aspect_ratio
         self.seed = seed
