@@ -164,6 +164,7 @@ def _make_handler(registry: ProjectRegistry):
                 return self._not_found()
             manifest = context.manager.read_manifest(ctx)
             allowed = {image.filename for image in manifest.images}
+            allowed.update({image.raw_filename for image in manifest.images if image.raw_filename})
             if filename not in allowed:
                 return self._not_found()
             file_path = ctx.session_dir / filename
@@ -1609,6 +1610,7 @@ def _app_html() -> str:
       }
 
       async function loadSlots(options = {}) {
+        const { initial = false, forceReload = false } = options;
         if (!state.projectId) {
           state.slots = [];
           renderSlots();
@@ -1617,7 +1619,11 @@ def _app_html() -> str:
         }
         try {
           const params = new URLSearchParams({ project: state.projectId });
-          const res = await fetch(`/api/slots?${params.toString()}`);
+          if (forceReload) {
+            params.set('_', Date.now().toString());
+          }
+          const fetchOptions = forceReload ? { cache: 'no-store' } : {};
+          const res = await fetch(`/api/slots?${params.toString()}`, fetchOptions);
           if (!res.ok) throw new Error('Failed to load slots');
           const data = await res.json();
           state.slots = data.slots || [];
@@ -1640,7 +1646,7 @@ def _app_html() -> str:
             }
             updateSlotHeader();
           }
-          if (options.initial && state.pendingSlot) {
+          if (initial && state.pendingSlot) {
             const desiredSlot = state.pendingSlot;
             state.pendingSlot = null;
             if (desiredSlot) {
@@ -1712,11 +1718,17 @@ def _app_html() -> str:
         await loadSlotData(slotId);
       }
 
-      async function loadSlotData(slotId) {
+      async function loadSlotData(slotId, options = {}) {
         if (!state.projectId) return;
+        const { forceReload = false, preserveFilter = false } = options;
+        const previousFilter = preserveFilter ? state.sessionFilter : null;
         try {
           const params = new URLSearchParams({ project: state.projectId });
-          const res = await fetch(`/api/slots/${encodeURIComponent(slotId)}/sessions?${params.toString()}`);
+          if (forceReload) {
+            params.set('_', Date.now().toString());
+          }
+          const fetchOptions = forceReload ? { cache: 'no-store' } : {};
+          const res = await fetch(`/api/slots/${encodeURIComponent(slotId)}/sessions?${params.toString()}`, fetchOptions);
           if (!res.ok) throw new Error('Failed to load slot data');
           const data = await res.json();
           state.slot = data.slot || slotId;
@@ -1730,7 +1742,12 @@ def _app_html() -> str:
           }
           state.sessions = Array.isArray(data.sessions) ? data.sessions : [];
           state.variants = Array.isArray(data.variants) ? data.variants : [];
-          state.sessionFilter = null;
+          if (preserveFilter && previousFilter) {
+            const hasFilter = state.sessions.some((session) => session.sessionId === previousFilter);
+            state.sessionFilter = hasFilter ? previousFilter : null;
+          } else {
+            state.sessionFilter = null;
+          }
           state.currentSelection = data.currentSelection || null;
           updateProjectSummary();
           updateDocumentTitle();
@@ -1987,8 +2004,8 @@ def _app_html() -> str:
           });
           if (!res.ok) throw new Error('Promote failed');
           showToast(`Promoted session ${variant.sessionId} #${variant.variantIndex}`);
-          await loadSlotData(variant.slot);
-          await loadSlots();
+          await loadSlotData(variant.slot, { forceReload: true, preserveFilter: true });
+          await loadSlots({ forceReload: true });
         } catch (error) {
           console.error(error);
           showToast('Unable to promote variant', 'error');
@@ -2045,13 +2062,13 @@ def _app_html() -> str:
       }
 
       refreshSlotsBtn.addEventListener('click', () => {
-        loadSlots();
+        loadSlots({ forceReload: true });
       });
 
       refreshSlotBtn.addEventListener('click', async () => {
         if (state.slot) {
-          await loadSlotData(state.slot);
-          await loadSlots();
+          await loadSlotData(state.slot, { forceReload: true, preserveFilter: true });
+          await loadSlots({ forceReload: true });
         }
       });
 
